<?php
/**
 * Capiton theme functions
 */

// Emable The custom Menu
register_nav_menu( 'primary', __( 'Primary Menu', 'capiton' ) );

// Enable Translation
load_theme_textdomain( 'themefurnace', TEMPLATEPATH.'/languages' );

// Theme customizer
include('includes/customizer.php');

// Style the Tag Cloud
function custom_tag_cloud_widget($args) {
	$args['largest'] = 12; //largest tag
	$args['smallest'] = 12; //smallest tag
	$args['unit'] = 'px'; //tag font unit
	$args['number'] = '8'; //number of tags
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'custom_tag_cloud_widget' );

/**
 * Replaces "[...]" (appended to automatically generated excerpts) with an ellipsis) and sets character length to 35
 */
function wp_new_excerpt($text)
{
	if ($text == '')
	{
		$text = get_the_content('');
		$text = strip_shortcodes( $text );
		$text = apply_filters('the_content', $text);
		$text = str_replace(']]>', ']]>', $text);
		$text = strip_tags($text);
		$text = nl2br($text);
		$excerpt_length = apply_filters('excerpt_length', 30);
		$words = explode(' ', $text, $excerpt_length + 1);
		if (count($words) > $excerpt_length) {
			array_pop($words);
			array_push($words, '');
			$text = implode(' ', $words);
		}
	}
	return $text;
}
remove_filter('get_the_excerpt', 'wp_trim_excerpt');
add_filter('get_the_excerpt', 'wp_new_excerpt');


/**
 * Get our wp_nav_menu() fallback, wp_page_menu(), to show a home link.
 */
function capiton_page_menu_args( $args ) {
	$args['show_home'] = true;
	return $args;
}
add_filter( 'wp_page_menu_args', 'capiton_page_menu_args' );

/**
 * Register our sidebars and widgetized areas. 
 *
 */
function themefurnace_widgets_init() {


	register_sidebar(array(
		'name' => 'Footer 1',
		'id' => 'avando-sidebar-footer-1',
		'before_widget' => '<div class="footerwidget">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="footerwidgettitle">',
		'after_title' => '</h3>',
	));
	register_sidebar(array(
		'name' => 'Footer 2',
		'id' => 'avando-sidebar-footer-2',
		'before_widget' => '<div class="footerwidget">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="footerwidgettitle">',
		'after_title' => '</h3>',
	));
	register_sidebar(array(
		'name' => 'Footer 3',
		'id' => 'avando-sidebar-footer-3',
		'before_widget' => '<div class="footerwidget">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="footerwidgettitle">',
		'after_title' => '</h3>',
	));
	register_sidebar(array(
		'name' => 'Footer 4',
		'id' => 'avando-sidebar-footer-4',
		'before_widget' => '<div class="footerwidget">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="footerwidgettitle">',
		'after_title' => '</h3>',
	));
	register_sidebar(array(
		'name' => 'Blog',
		'id' => 'avando-sidebar-blog',
		'before_widget' => '<div class="sidebarwidget">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="sidebartitle">',
		'after_title' => '</h3>',
	));
	register_sidebar(array(
		'name' => 'Page',
		'id' => 'avando-sidebar-page',
		'before_widget' => '<div class="sidebarwidget">',
		'after_widget' => '</div>',
		'before_title' => '<h3 class="sidebartitle">',
		'after_title' => '</h3>',
	));

	
}
add_action( 'widgets_init', 'themefurnace_widgets_init' );

/**
 * Thanks to Kriesi for Pagination code - http://www.kriesi.at/archives/how-to-build-a-wordpress-post-pagination-without-plugin
 */

function themefurnace_pagination($pages = '', $range = 2)
{  
     $showitems = ($range * 2)+1;  

     global $paged;
     if(empty($paged)) $paged = 1;

     if($pages == '')
     {
         global $wp_query;
         $pages = $wp_query->max_num_pages;
         if(!$pages)
         {
             $pages = 1;
         }
     }   

     if(1 != $pages)
     {
         echo "<div class='pagination'>";
         if($paged > 2 && $paged > $range+1 && $showitems < $pages) echo "<a href='".get_pagenum_link(1)."'>&laquo;</a>";
         if($paged > 1 && $showitems < $pages) echo "<a href='".get_pagenum_link($paged - 1)."'>&lsaquo;</a>";

         for ($i=1; $i <= $pages; $i++)
         {
             if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems ))
             {
                 echo ($paged == $i)? "<span class='current'>".$i."</span>":"<a href='".get_pagenum_link($i)."' class='inactive' >".$i."</a>";
             }
         }

         if ($paged < $pages && $showitems < $pages) echo "<a href='".get_pagenum_link($paged + 1)."'>&rsaquo;</a>";  
         if ($paged < $pages-1 &&  $paged+$range-1 < $pages && $showitems < $pages) echo "<a href='".get_pagenum_link($pages)."'>&raquo;</a>";
         echo "</div>\n";
     }
}


/**
 * Loading jQuery
 */
 
function loading_jquery() {
	wp_deregister_script( 'comment-reply' );
    wp_enqueue_script( 'jquery' );
    wp_register_script('jqueryfix', get_template_directory_uri() . '/js/jquery-fix.js', array('jquery'), '1.0');
    wp_enqueue_script('jqueryfix');

}     
 
add_action('wp_enqueue_scripts', 'loading_jquery');


/**
 * Template for comments and pingbacks.
 *
 * To override this walker in a child theme without modifying the comments template
 * simply create your own sympalpress_comment(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 */
 if ( ! function_exists( 'sympalpress_comment' ) ) :
 
function capiton_comment( $comment, $args, $depth ) {
	$GLOBALS['comment'] = $comment;
	switch ( $comment->comment_type ) :
		case '' :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<div id="comment-<?php comment_ID(); ?>">
		<div class="comment-author vcard">
			<?php echo get_avatar( $comment, 45 ); ?>
			<?php printf( __( get_comment_author_link() ) ); ?>
		</div><!-- .comment-author .vcard -->
		<?php if ( $comment->comment_approved == '0' ) : ?>
			<em><?php _e( 'Your comment is awaiting moderation.', 'ThemeFurnace' ); ?></em>
			<br />
		<?php endif; ?>

		<div class="comment-meta commentmetadata"><a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ); ?>">
			<?php
				/* translators: 1: date, 2: time */
				printf( __( '%1$s at %2$s', 'capiton' ), get_comment_date(),  get_comment_time() ); ?></a><?php edit_comment_link( __( '(Edit)', 'capiton' ), ' ' );
			?>
		</div><!-- .comment-meta .commentmetadata -->

		<div class="comment-body"><?php comment_text(); ?></div>

		<div class="reply">
			<?php comment_reply_link( array_merge( $args, array( 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
		</div><!-- .reply -->
	</div><!-- #comment-##  -->

	<?php
			break;
		case 'pingback'  :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'ThemeFurnace' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __('(Edit)', 'capiton'), ' ' ); ?></p>
	<?php
			break;
	endswitch;
}
endif;
array(
	'author' => '<p class="comment-form-author">...',
	'email'  => '<p class="comment-form-email">...',
	'url'    => '<p class="comment-form-url">...'
);


	// This theme uses Featured Images (also known as post thumbnails) for per-post/per-page Custom Header images
	add_theme_support( 'post-thumbnails' );
	
	//This feature enables post and comment RSS feed links to head. 
	add_theme_support( 'automatic-feed-links' );
	
	//This feature enables post and comment RSS feed links to head. 
	add_custom_background();
	
	//Content Width
	if ( ! isset( $content_width ) ) $content_width = 900;

// post thumbnail support

	if ( function_exists( 'add_image_size' ) ) add_theme_support( 'post-thumbnails' );
	if ( function_exists( 'add_image_size' ) ) { 
	add_image_size( 'post-full');
	add_image_size( 'home-thumb', 530, 180, true );
}


function custom_theme_css() {
	global $up_options;
	
	if(!empty($up_options->styles)) {
		echo '<link rel="stylesheet" type="text/css" href="'.get_template_directory_uri().'/css/'.$up_options->styles.'.css"/>';
	}
				
	$accent_color = get_option('accent_color');
	$slider_css = '';
	
	if(empty($accent_color)) $accent_color = '#ff0000';
	
	if(!empty($up_options->nivo_settings_sliderHeight)) { 
	    $slider_css = ' #slider { max-height: '.$up_options->nivo_settings_sliderHeight.'px;}';
	}
	
	if(empty($up_options->title_font) || empty($up_options->body_font)) {
	    echo '<link rel="stylesheet" type="text/css" href="http://fonts.googleapis.com/css?family=Open+Sans:400,300,600,700,300italic">';
	}
	
	echo '<style type="text/css">'.$slider_css.'
	a, .posttitle a:hover, .postmeta a:hover, .footerwidget a:hover , #main-nav .current-menu-item a, #main-nav .current_page_item a, .selected, .footerwidget li, .sidebarwidget li   { color: '.$accent_color.';}
	.postformat, .slidetitle span, .flex-direction-nav li a { background-color: '.$accent_color.' !important;}
	.postmeta a:hover , body , #main-nav ul ul li a:hover, #main-nav .current-menu-item a, #main-nav .current_page_item a, .selected, #main-nav li a:hover{border-color: '.$accent_color.'; }
	</style>';
}